<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Console\Command;

use Magento\Framework\Console\Cli;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Amasty\ShopbyMFTF3\Model\ResourceModel\FilterAnalyticTmp\CollectionFactory as CollectionFilterAnalyticTmpFactory;

class AssertAnalyticsEmptyCommand extends Command
{
    /**
     * @var CollectionFilterAnalyticTmpFactory
     */
    private $collectionFilterAnalyticTmpFactory;

    public function __construct(
        CollectionFilterAnalyticTmpFactory $collectionFilterAnalyticTmpFactory
    ) {
        parent::__construct();
        $this->collectionFilterAnalyticTmpFactory = $collectionFilterAnalyticTmpFactory;
    }

    protected function configure()
    {
        $this->setName('mftf:iln:assert-empty-analytic')
            ->setDescription('Assert is table not contains some filters option_ids.');
        $this->setDefinition(
            [
                new InputArgument(
                    'ids',
                    InputArgument::REQUIRED,
                    'Attribute option IDs.'
                )
            ]
        );
    }
    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $stringOptionIds = (string)$input->getArgument('ids');
        $ids = explode(',', $stringOptionIds);

        foreach ($ids as $id){
            $collectionFilterAnalyticTpm = $this->collectionFilterAnalyticTmpFactory->create();
            $filters = $collectionFilterAnalyticTpm->addFieldToFilter('main_table.option_id', ['in' => [$id]]);

            if ($filters->count()) {
                $output->writeln(
                    '<info>False! Table has filters with option_id "' . $id . '". Script is finished.</info>'
                );

                return Cli::RETURN_FAILURE;
            }
        }

        $output->writeln('<info>True! Posts is not found in table! Script is finished.</info>');

        return Cli::RETURN_SUCCESS;
    }

}

