<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Console\Command;

use Magento\Framework\Console\Cli;
use Magento\Framework\Stdlib\DateTime\DateTime;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Amasty\ShopbyMFTF3\Model\ResourceModel\FilterAnalyticTmp\CollectionFactory as CollectionFilterAnalyticTmpFactory;

class FilterAnalyticsChangeCreatedAtCommand extends Command
{
    /**
     * @var DateTime
     */
    private $dateTime;

    /**
     * @var CollectionFilterAnalyticTmpFactory
     */
    private $collectionFilterAnalyticTmpFactory;

    public function __construct(
        DateTime $dateTime,
        CollectionFilterAnalyticTmpFactory $collectionFilterAnalyticTmpFactory
    ) {
        parent::__construct();
        $this->dateTime = $dateTime;
        $this->collectionFilterAnalyticTmpFactory = $collectionFilterAnalyticTmpFactory;
    }

    protected function configure()
    {
        $this->setName('mftf:iln:change-created-analytic')
            ->setDescription('Change created at column value in pref_amasty_shopbyfilteranalytics_tmp tab');
        $this->setDefinition(
            [
                new InputArgument(
                    'ids',
                    InputArgument::REQUIRED,
                    'Attribute option IDs.'
                )
            ]
        );
    }
    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $stringOptionIds = (string)$input->getArgument('ids');
        $ids = explode(',', $stringOptionIds, 3);

        if (isset($ids[2]) && strstr($ids[2], ',') !== false) {
                $ids[2] = str_replace(strstr($ids[2],','), '', $ids[2]);
        }

        $arrayTimeChange = ['year', 'month', 'day'];
        $changeType = 0;

        foreach ($ids as $id){
            $changeCount = 1;
            $collectionFilterAnalyticTpm = $this->collectionFilterAnalyticTmpFactory->create();
            $filters = $collectionFilterAnalyticTpm->addFieldToFilter('main_table.option_id', ['in' => [$id]]);

            foreach ($filters as $filter){
                $origDate = $filter->getCreatedAt();
                $filter->setCreatedAt($this->dateTime->date(
                    null, strtotime($origDate . ' -' . $changeCount . ' ' . $arrayTimeChange[$changeType]))
                );

                $collectionFilterAnalyticTpm->getResource()->save($filter);
                $changeCount++;
            }

            $changeType++;
        }

        $output->writeln('<info>Script is finished.</info>');

        return Cli::RETURN_SUCCESS;
    }

}

