<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Console\Command;

use Amasty\ShopbyMFTF3\Model\XmlGenerator\AttributesOptions;
use Magento\Framework\App\Area;
use Magento\Framework\App\State;
use Magento\Framework\Console\Cli;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Amasty\ShopbyMFTF3\Model\XmlGenerator\Attributes;

class UpdateIdsCommand extends Command
{
    /**
     * @var State
     */
    private $state;

    /**
     * @var Attributes
     */
    private $attributes;

    /**
     * @var AttributesOptions
     */
    private $attributesOptions;

    public function __construct(
        State $state,
        Attributes $attributes,
        AttributesOptions $attributesOptions
    ) {
        $this->state = $state;
        $this->attributes = $attributes;
        $this->attributesOptions = $attributesOptions;
        parent::__construct();
    }

    protected function configure()
    {
        parent::configure();
        $this->setName('mftf:iln:parse-products')
            ->setDescription('Generate Products Data for MFTF Tests');
    }

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     *
     * @return void
     */
    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $this->state->setAreaCode(Area::AREA_FRONTEND);

        $this->attributes->generate();
        $this->attributesOptions->generate();

        $output->writeln('<info>Script is finished.</info>');

        return Cli::RETURN_SUCCESS;
    }
}
