<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\Service;

use Magento\Catalog\Model\Product;
use Magento\Eav\Api\AttributeRepositoryInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;

class AttributeDataGenerator
{
    /**
     * @var AttributeRepositoryInterface
     */
    private $attributeRepository;

    public function __construct(
        AttributeRepositoryInterface $attributeRepository
    ) {
        $this->attributeRepository = $attributeRepository;
    }

    /**
     * @param array $productAttributes
     *
     * @return array
     *
     * @throws LocalizedException
     **/
    public function getData(array $productAttributes): array
    {
        return $this->getProductAttributesIdsArray($productAttributes);
    }

    /**
     * @throws LocalizedException
     */
    private function getProductAttributesIdsArray(array $productAttributes): array
    {
        $array = [];

        foreach ($productAttributes as $key => $attributeCode) {
            if ($key == 'entity_object_type'){
                continue;
            }

            $keyName = str_replace('ids', 'IDS', $attributeCode);
            $keyName = str_replace(' ', '', ucwords(str_replace('_', ' ', (string)$keyName))) . 'ID';
            try {
                $array[$keyName] = $this->attributeRepository->get(Product::ENTITY, $attributeCode)->getAttributeId();
            } catch (NoSuchEntityException $e) {
                throw new \Magento\Framework\Exception\LocalizedException(__('Cannot specify attribute.'), $e);
            }
        }

        return $array;
    }
}
