<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\Service;

use Amasty\ShopbyMFTF3\Model\ResourceModel\OptionValue\CollectionFactory as CollectionOptionValueFactory;

class AttributeOptionDataGenerator
{
    /**
     * @var CollectionOptionValueFactory
     */
    private $collectionOptionValueFactory;

    public function __construct(
        CollectionOptionValueFactory $collectionOptionValueFactory
    ) {
        $this->collectionOptionValueFactory = $collectionOptionValueFactory;
    }

    /**
     * @param array $optionsArray
     *
     * @return array
     */
    public function getData(array $optionsArray): array
    {
        return $this->getAttributesOptionsIdsArray($optionsArray);
    }

    private function getAttributesOptionsIdsArray(array $optionsArray): array
    {
        $arrayIds = [];

        foreach ($optionsArray as $key => $optionValue){
            if ($key == 'entity_object_type'){
                continue;
            }

            $keyName = str_replace('ids', 'IDS', $optionValue);
            $keyName = str_replace(' ', '', ucwords(str_replace(['_', '-'], ' ', (string)$keyName))) . 'ID';

            $collectionOptionValue = $this->collectionOptionValueFactory->create();
            $option = $collectionOptionValue->addFieldToFilter(
                'main_table.value', ['in' => [$optionValue]]
            )->getFirstItem();

            $arrayIds[$keyName] = $option->getData('option_id');
        }

        return $arrayIds;
    }
}
