<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\Service\ContentXmlGenerator;

class ContentXmlGenerator
{
    /** Generate of header Xml MFTF Tag
     *
     * @return string
     */
    private function generateHeaderDataXml(): string
    {
        return '<?xml version="1.0" encoding="UTF-8"?>'
            . PHP_EOL
            . '<entities xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" '
            . 'xsi:noNamespaceSchemaLocation="urn:magento:mftf:Test/etc/dataSchema.xsd">'
            . PHP_EOL
            . PHP_EOL;
    }

    /** Return of header Xml MFTF Data Tag
     *
     * @return string
     */
    public function getHeaderDataXml (): string
    {
        return $this->generateHeaderDataXml();
    }

    /** Generate of footer Xml MFTF Data Main Tag
     *
     * @return string
     */
    private function generateFooterDataXml(): string
    {
        return '</entities>';
    }

    /** Return of footer Xml MFTF Data Main Tag
     *
     * @return string
     */
    public function getFooterDataXml(): string
    {
        return $this->generateFooterDataXml();
    }

    /** Generate of header Xml MFTF Data <entity> Tag
     *
     * @param string $name
     * @param string $type
     * @return string
     */
    private function generateEntityHeaderXml(string $name, string $type): string
    {
        return "\t" . '<entity name="' . $name . '" type="' . $type . '">' . PHP_EOL;
    }

    /** Return of header Xml MFTF Data <entity> Tag
     *
     * @param string $name
     * @param string $type
     * @return string
     */
    public function getEntityHeaderXml(string $name, string $type): string
    {
        return $this->generateEntityHeaderXml($name, $type);
    }

    /** Generate of footer Xml MFTF Data Tag
     *
     * @return string
     */
    private function generateEntityFooterXml(): string
    {
        return "\t" . '</entity>' . PHP_EOL;
    }

    /** Return of footer Xml MFTF Data Tag
     *
     * @return string
     */
    public function getEntityFooterXml(): string
    {
        return $this->generateEntityFooterXml();
    }

    /** Generate of footer Xml MFTF Data <data> Tag
     *
     * @param string $key
     * @param string $value
     * @return string
     */
    private function generateEntityDataStringXml(string $key, string $value): string
    {
        return "\t\t" . '<data key="' . $key . '">' . $value . '</data>' . PHP_EOL;
    }

    /** Return of footer Xml MFTF Data <data> Tag
     *
     * @param string $key
     * @param string $value
     * @return string
     */
    public function getDataStringXml(string $key, string $value): string
    {
        return $this->generateEntityDataStringXml($key, $value);
    }

}
