<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\Service\ContentXmlGenerator;

class DataContentXmlGenerator
{
    /**
     * @var ContentXmlGenerator
     */
    private $contentXmlGenerator;

    public function __construct(
        ContentXmlGenerator $contentXmlGenerator
    ) {
        $this->contentXmlGenerator = $contentXmlGenerator;
    }

    /** Return content for Data files
     *
     * @param array $objArray
     * @return string
     */
    public function getDataContent(
        array $objArray
    ): string {
        $content = '';

        foreach ($objArray as $nameObj => $valuesObj) {
            $objContent = '';
            foreach ($valuesObj as $key => $value) {
                if ($key == 'entity_object_type') {
                    continue;
                }

                $objContent .= $this->contentXmlGenerator->getDataStringXml(
                    $key, str_replace(['&', '™'], ['&amp;', '&#8482;'], $value)
                );
            }

            $content .= $this->contentXmlGenerator->getEntityHeaderXml($nameObj, $valuesObj['entity_object_type'])
                . $objContent
                . $this->contentXmlGenerator->getEntityFooterXml();
        }

        $beforeTag = $this->contentXmlGenerator->getHeaderDataXml();
        $afterTag = $this->contentXmlGenerator->getFooterDataXml() . PHP_EOL;

        return $beforeTag . $content . $afterTag;
    }
}
