<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\Service;

use Magento\Framework\Module\Dir\Reader;

class XmlDataReader
{
    const DATA_FILES_PATH = '/Test/Mftf/Data/';
    const MODULE_NAME = 'Amasty_ShopbyMFTF3';

    /**
     * @var Reader
     */
    private $dirReader;

    public function __construct(
        Reader $dirReader
    ) {
        $this->dirReader = $dirReader;
    }

    public function getDataArray(string $filename): array
    {
        return $this->generateArrayFromXml($filename);
    }

    private function generateArrayFromXml(string $filename): array
    {
        $filePath = $this->dirReader->getModuleDir('', self::MODULE_NAME) . self::DATA_FILES_PATH . $filename;
        $objectXml = simplexml_load_file($filePath);

        return $this->buildArrayFromXml($objectXml);
    }

    public function buildArrayFromXml($objectXml): array
    {
        $array = [];

        foreach ($objectXml as $entity) {
            foreach ($entity->children()->data as $data){
                    $array[(string)$entity->attributes()->name][(string)$data->attributes()->key] = (string)$data[0];
            }
            $array[(string)$entity->attributes()->name]['entity_object_type'] = (string)$entity->attributes()->type;
        }

        return $array;
    }

}
