<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model;

use Magento\Framework\Exception\FileSystemException;
use Magento\Framework\Filesystem\Driver\File as FileDriver;
use Magento\Framework\Module\Dir\Reader;

class XmlDataRewriter
{
    const DATA_FILES_PATH = '/Test/Mftf/Data/';
    const MODULE_NAME = 'Amasty_ShopbyMFTF3';

    /**
     * @var Reader
     */
    private $dirReader;

    /**
     * @var FileDriver
     */
    private $fileDriver;

    public function __construct(
        Reader $dirReader,
        FileDriver $fileDriver
    ) {
        $this->dirReader = $dirReader;
        $this->fileDriver = $fileDriver;
    }

    /** Put result content to file. Rewrite file.
     *
     * @param string $filename
     * @param string $content
     *
     * @return void
     * @throws FileSystemException
     */
    public function rewriteDataXmlFile(string $filename, string $content): void
    {
        $filePath = $this->getDataXmlDir() . $filename;
        $this->fileDriver->filePutContents($filePath, $content);
    }

    /** For return Data directory path
     *
     * @return string
     */
    private function getDataXmlDir(): string
    {
        return $this->dirReader->getModuleDir('', self::MODULE_NAME) . self::DATA_FILES_PATH;
    }

}
