<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Improved Layered Navigation MFTF 3 for Magento 2 (System)
 */

namespace Amasty\ShopbyMFTF3\Model\XmlGenerator;

use Amasty\ShopbyMFTF3\Model\Service\AttributeDataGenerator;
use Amasty\ShopbyMFTF3\Model\Service\ContentXmlGenerator\DataContentXmlGenerator;
use Amasty\ShopbyMFTF3\Model\Service\XmlDataReader;
use Amasty\ShopbyMFTF3\Model\XmlDataRewriter;

class Attributes implements XmlGenerator
{
    const PRODUCT_ATTRIBUTES_FILE_NAME = 'AttributesAndOptionsIDsAndTitlesData.xml';
    const ATTR_IDS = 'AttrIDsStorage';
    const ATTR_TITLE = 'AttrSeoTitlesStorage';

    /**
     * @var AttributeDataGenerator
     */
    private $attributeDataGenerator;

    /**
     * @var DataContentXmlGenerator
     */
    private $dataContentXmlGenerator;

    /**
     * @var XmlDataRewriter
     */
    private $xmlDataRewriter;

    /**
     * @var XmlDataReader
     */
    private $xmlDataReader;

    public function __construct(
        XmlDataReader $xmlDataReader,
        AttributeDataGenerator $attributeDataGenerator,
        DataContentXmlGenerator $dataContentXmlGenerator,
        XmlDataRewriter $xmlDataRewriter
    ) {
        $this->attributeDataGenerator = $attributeDataGenerator;
        $this->xmlDataReader = $xmlDataReader;
        $this->dataContentXmlGenerator = $dataContentXmlGenerator;
        $this->xmlDataRewriter = $xmlDataRewriter;
    }

    public function generate(): void
    {
        // get arrays from file
        $attributes = $this->xmlDataReader->getDataArray(self::PRODUCT_ATTRIBUTES_FILE_NAME);

        // get product attributes values (ids) and link new values to array from file
        $newValues = $this->attributeDataGenerator->getData($attributes[self::ATTR_TITLE]);
        foreach ($newValues as $key => $value){
            $attributes[self::ATTR_IDS][$key] = $value;
        }

        // get product attributes xml content and rewrite file
        $contentAttributesXml = $this->dataContentXmlGenerator->getDataContent(
            $attributes);
        $this->xmlDataRewriter->rewriteDataXmlFile(self::PRODUCT_ATTRIBUTES_FILE_NAME, $contentAttributesXml);
    }
}
